JoinHandle

Struct JoinHandle 

pub struct JoinHandle<T: 'static> { /* private fields */ }
JoinHandle provides method to retrieve result of associated cooperative task.

Implementations

Source

impl<T> JoinHandle<T>

pub fn join(self) -> Result<T, JoinError>

Waits for associated coroutine to finish and returns its result.

Panics
  • Panic if already joined by select!.
  • Panic if main coroutine finished.