Module task

Module task 

Lightweight concurrent execution units based on coroutines.

Structs

Builder
Builder for concurrent task.
JoinHandle
JoinHandle provides method to retrieve result of associated concurrent task.
Session
Session provides method to block current coroutine until waking by SessionWaker.
SessionWaker
SessionWaker provides method to wake associated Session.

Functions

session
Constructs cooperative facilities to wait and wake coroutine across task boundary.
spawn
Spawns a concurrent task and returns a JoinHandle for it.
yield_now
Yields task for next scheduling cycle.