pub struct JoinHandle<T: Send + 'static> { /* private fields */ }
JoinHandle provides method to retrieve result of associated concurrent task.

Implementations

Waits for associated task to finish and returns its result.